# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from unifieddatalibrary import Unifieddatalibrary, AsyncUnifieddatalibrary
from unifieddatalibrary.types import (
    OperatingunitremarkGetResponse,
    OperatingunitremarkListResponse,
    OperatingunitremarkTupleResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestOperatingunitremark:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Unifieddatalibrary) -> None:
        operatingunitremark = client.operatingunitremark.create(
            classification_marking="U",
            data_mode="TEST",
            id_operating_unit="OperatingUnit-ID",
            source="some.user",
            text="This is a remark",
        )
        assert operatingunitremark is None

    @parametrize
    def test_method_create_with_all_params(self, client: Unifieddatalibrary) -> None:
        operatingunitremark = client.operatingunitremark.create(
            classification_marking="U",
            data_mode="TEST",
            id_operating_unit="OperatingUnit-ID",
            source="some.user",
            text="This is a remark",
            id="0167f577-e06c-358e-85aa-0a07a730bdd0",
            alt_rmk_id="123456ABC",
            code="M",
            name="Remark name",
            origin="THIRD_PARTY_DATASOURCE",
            type="Restriction",
        )
        assert operatingunitremark is None

    @parametrize
    def test_raw_response_create(self, client: Unifieddatalibrary) -> None:
        response = client.operatingunitremark.with_raw_response.create(
            classification_marking="U",
            data_mode="TEST",
            id_operating_unit="OperatingUnit-ID",
            source="some.user",
            text="This is a remark",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = response.parse()
        assert operatingunitremark is None

    @parametrize
    def test_streaming_response_create(self, client: Unifieddatalibrary) -> None:
        with client.operatingunitremark.with_streaming_response.create(
            classification_marking="U",
            data_mode="TEST",
            id_operating_unit="OperatingUnit-ID",
            source="some.user",
            text="This is a remark",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = response.parse()
            assert operatingunitremark is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list(self, client: Unifieddatalibrary) -> None:
        operatingunitremark = client.operatingunitremark.list()
        assert_matches_type(OperatingunitremarkListResponse, operatingunitremark, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Unifieddatalibrary) -> None:
        response = client.operatingunitremark.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = response.parse()
        assert_matches_type(OperatingunitremarkListResponse, operatingunitremark, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Unifieddatalibrary) -> None:
        with client.operatingunitremark.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = response.parse()
            assert_matches_type(OperatingunitremarkListResponse, operatingunitremark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_count(self, client: Unifieddatalibrary) -> None:
        operatingunitremark = client.operatingunitremark.count()
        assert_matches_type(str, operatingunitremark, path=["response"])

    @parametrize
    def test_raw_response_count(self, client: Unifieddatalibrary) -> None:
        response = client.operatingunitremark.with_raw_response.count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = response.parse()
        assert_matches_type(str, operatingunitremark, path=["response"])

    @parametrize
    def test_streaming_response_count(self, client: Unifieddatalibrary) -> None:
        with client.operatingunitremark.with_streaming_response.count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = response.parse()
            assert_matches_type(str, operatingunitremark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_create_bulk(self, client: Unifieddatalibrary) -> None:
        operatingunitremark = client.operatingunitremark.create_bulk(
            body=[
                {
                    "classification_marking": "U",
                    "data_mode": "TEST",
                    "id_operating_unit": "OperatingUnit-ID",
                    "source": "some.user",
                    "text": "This is a remark",
                }
            ],
        )
        assert operatingunitremark is None

    @parametrize
    def test_raw_response_create_bulk(self, client: Unifieddatalibrary) -> None:
        response = client.operatingunitremark.with_raw_response.create_bulk(
            body=[
                {
                    "classification_marking": "U",
                    "data_mode": "TEST",
                    "id_operating_unit": "OperatingUnit-ID",
                    "source": "some.user",
                    "text": "This is a remark",
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = response.parse()
        assert operatingunitremark is None

    @parametrize
    def test_streaming_response_create_bulk(self, client: Unifieddatalibrary) -> None:
        with client.operatingunitremark.with_streaming_response.create_bulk(
            body=[
                {
                    "classification_marking": "U",
                    "data_mode": "TEST",
                    "id_operating_unit": "OperatingUnit-ID",
                    "source": "some.user",
                    "text": "This is a remark",
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = response.parse()
            assert operatingunitremark is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get(self, client: Unifieddatalibrary) -> None:
        operatingunitremark = client.operatingunitremark.get(
            "id",
        )
        assert_matches_type(OperatingunitremarkGetResponse, operatingunitremark, path=["response"])

    @parametrize
    def test_raw_response_get(self, client: Unifieddatalibrary) -> None:
        response = client.operatingunitremark.with_raw_response.get(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = response.parse()
        assert_matches_type(OperatingunitremarkGetResponse, operatingunitremark, path=["response"])

    @parametrize
    def test_streaming_response_get(self, client: Unifieddatalibrary) -> None:
        with client.operatingunitremark.with_streaming_response.get(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = response.parse()
            assert_matches_type(OperatingunitremarkGetResponse, operatingunitremark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get(self, client: Unifieddatalibrary) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.operatingunitremark.with_raw_response.get(
                "",
            )

    @parametrize
    def test_method_queryhelp(self, client: Unifieddatalibrary) -> None:
        operatingunitremark = client.operatingunitremark.queryhelp()
        assert operatingunitremark is None

    @parametrize
    def test_raw_response_queryhelp(self, client: Unifieddatalibrary) -> None:
        response = client.operatingunitremark.with_raw_response.queryhelp()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = response.parse()
        assert operatingunitremark is None

    @parametrize
    def test_streaming_response_queryhelp(self, client: Unifieddatalibrary) -> None:
        with client.operatingunitremark.with_streaming_response.queryhelp() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = response.parse()
            assert operatingunitremark is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_tuple(self, client: Unifieddatalibrary) -> None:
        operatingunitremark = client.operatingunitremark.tuple(
            columns="columns",
        )
        assert_matches_type(OperatingunitremarkTupleResponse, operatingunitremark, path=["response"])

    @parametrize
    def test_raw_response_tuple(self, client: Unifieddatalibrary) -> None:
        response = client.operatingunitremark.with_raw_response.tuple(
            columns="columns",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = response.parse()
        assert_matches_type(OperatingunitremarkTupleResponse, operatingunitremark, path=["response"])

    @parametrize
    def test_streaming_response_tuple(self, client: Unifieddatalibrary) -> None:
        with client.operatingunitremark.with_streaming_response.tuple(
            columns="columns",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = response.parse()
            assert_matches_type(OperatingunitremarkTupleResponse, operatingunitremark, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncOperatingunitremark:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncUnifieddatalibrary) -> None:
        operatingunitremark = await async_client.operatingunitremark.create(
            classification_marking="U",
            data_mode="TEST",
            id_operating_unit="OperatingUnit-ID",
            source="some.user",
            text="This is a remark",
        )
        assert operatingunitremark is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncUnifieddatalibrary) -> None:
        operatingunitremark = await async_client.operatingunitremark.create(
            classification_marking="U",
            data_mode="TEST",
            id_operating_unit="OperatingUnit-ID",
            source="some.user",
            text="This is a remark",
            id="0167f577-e06c-358e-85aa-0a07a730bdd0",
            alt_rmk_id="123456ABC",
            code="M",
            name="Remark name",
            origin="THIRD_PARTY_DATASOURCE",
            type="Restriction",
        )
        assert operatingunitremark is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.operatingunitremark.with_raw_response.create(
            classification_marking="U",
            data_mode="TEST",
            id_operating_unit="OperatingUnit-ID",
            source="some.user",
            text="This is a remark",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = await response.parse()
        assert operatingunitremark is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.operatingunitremark.with_streaming_response.create(
            classification_marking="U",
            data_mode="TEST",
            id_operating_unit="OperatingUnit-ID",
            source="some.user",
            text="This is a remark",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = await response.parse()
            assert operatingunitremark is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list(self, async_client: AsyncUnifieddatalibrary) -> None:
        operatingunitremark = await async_client.operatingunitremark.list()
        assert_matches_type(OperatingunitremarkListResponse, operatingunitremark, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.operatingunitremark.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = await response.parse()
        assert_matches_type(OperatingunitremarkListResponse, operatingunitremark, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.operatingunitremark.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = await response.parse()
            assert_matches_type(OperatingunitremarkListResponse, operatingunitremark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_count(self, async_client: AsyncUnifieddatalibrary) -> None:
        operatingunitremark = await async_client.operatingunitremark.count()
        assert_matches_type(str, operatingunitremark, path=["response"])

    @parametrize
    async def test_raw_response_count(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.operatingunitremark.with_raw_response.count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = await response.parse()
        assert_matches_type(str, operatingunitremark, path=["response"])

    @parametrize
    async def test_streaming_response_count(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.operatingunitremark.with_streaming_response.count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = await response.parse()
            assert_matches_type(str, operatingunitremark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_create_bulk(self, async_client: AsyncUnifieddatalibrary) -> None:
        operatingunitremark = await async_client.operatingunitremark.create_bulk(
            body=[
                {
                    "classification_marking": "U",
                    "data_mode": "TEST",
                    "id_operating_unit": "OperatingUnit-ID",
                    "source": "some.user",
                    "text": "This is a remark",
                }
            ],
        )
        assert operatingunitremark is None

    @parametrize
    async def test_raw_response_create_bulk(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.operatingunitremark.with_raw_response.create_bulk(
            body=[
                {
                    "classification_marking": "U",
                    "data_mode": "TEST",
                    "id_operating_unit": "OperatingUnit-ID",
                    "source": "some.user",
                    "text": "This is a remark",
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = await response.parse()
        assert operatingunitremark is None

    @parametrize
    async def test_streaming_response_create_bulk(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.operatingunitremark.with_streaming_response.create_bulk(
            body=[
                {
                    "classification_marking": "U",
                    "data_mode": "TEST",
                    "id_operating_unit": "OperatingUnit-ID",
                    "source": "some.user",
                    "text": "This is a remark",
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = await response.parse()
            assert operatingunitremark is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get(self, async_client: AsyncUnifieddatalibrary) -> None:
        operatingunitremark = await async_client.operatingunitremark.get(
            "id",
        )
        assert_matches_type(OperatingunitremarkGetResponse, operatingunitremark, path=["response"])

    @parametrize
    async def test_raw_response_get(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.operatingunitremark.with_raw_response.get(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = await response.parse()
        assert_matches_type(OperatingunitremarkGetResponse, operatingunitremark, path=["response"])

    @parametrize
    async def test_streaming_response_get(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.operatingunitremark.with_streaming_response.get(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = await response.parse()
            assert_matches_type(OperatingunitremarkGetResponse, operatingunitremark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get(self, async_client: AsyncUnifieddatalibrary) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.operatingunitremark.with_raw_response.get(
                "",
            )

    @parametrize
    async def test_method_queryhelp(self, async_client: AsyncUnifieddatalibrary) -> None:
        operatingunitremark = await async_client.operatingunitremark.queryhelp()
        assert operatingunitremark is None

    @parametrize
    async def test_raw_response_queryhelp(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.operatingunitremark.with_raw_response.queryhelp()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = await response.parse()
        assert operatingunitremark is None

    @parametrize
    async def test_streaming_response_queryhelp(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.operatingunitremark.with_streaming_response.queryhelp() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = await response.parse()
            assert operatingunitremark is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_tuple(self, async_client: AsyncUnifieddatalibrary) -> None:
        operatingunitremark = await async_client.operatingunitremark.tuple(
            columns="columns",
        )
        assert_matches_type(OperatingunitremarkTupleResponse, operatingunitremark, path=["response"])

    @parametrize
    async def test_raw_response_tuple(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.operatingunitremark.with_raw_response.tuple(
            columns="columns",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        operatingunitremark = await response.parse()
        assert_matches_type(OperatingunitremarkTupleResponse, operatingunitremark, path=["response"])

    @parametrize
    async def test_streaming_response_tuple(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.operatingunitremark.with_streaming_response.tuple(
            columns="columns",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            operatingunitremark = await response.parse()
            assert_matches_type(OperatingunitremarkTupleResponse, operatingunitremark, path=["response"])

        assert cast(Any, response.is_closed) is True
